@@ -56,6 +56,13 @@ NetworkManager::NetworkManagerPrivate::NetworkManagerPrivate()
     : watcher(DBUS_SERVICE, QDBusConnection::systemBus(), QDBusServiceWatcher::WatchForOwnerChange, this)
     , iface(NetworkManager::NetworkManagerPrivate::DBUS_SERVICE, NetworkManager::NetworkManagerPrivate::DBUS_DAEMON_PATH, QDBusConnection::systemBus())
     , nmState(0)
+    , m_isNetworkingEnabled(false)
+    , m_isWimaxEnabled(false)
+    , m_isWimaxHardwareEnabled(false)
+    , m_isWirelessEnabled(false)
+    , m_isWirelessHardwareEnabled(false)
+    , m_isWwanEnabled(false)
+    , m_isWwanHardwareEnabled(false)
 {
     connect(&watcher, SIGNAL(serviceRegistered(QString)), SLOT(daemonRegistered()));
     connect(&watcher, SIGNAL(serviceUnregistered(QString)), SLOT(daemonUnregistered()));
@@ -100,6 +107,12 @@ void NetworkManager::NetworkManagerPrivate::init()
         nmState = iface.state();
         emit statusChanged(convertNMState(nmState));
     }
+
+    if (m_connectivity != iface.connectivity()) {
+        m_connectivity = iface.connectivity();
+        emit connectivityChanged(convertConnectivity(m_connectivity));
+    }
+
     m_version = iface.version();
     parseVersion(m_version);
     if (m_isWirelessHardwareEnabled != iface.wirelessHardwareEnabled()) {
@@ -507,6 +520,26 @@ NMStringMap NetworkManager::NetworkManagerPrivate::permissions()
     return iface.GetPermissions();
 }
 
+NetworkManager::Connectivity NetworkManager::NetworkManagerPrivate::connectivity() const
+{
+    return convertConnectivity(m_connectivity);
+}
+
+QDBusPendingReply<uint> NetworkManager::NetworkManagerPrivate::checkConnectivity()
+{
+    return iface.CheckConnectivity();
+}
+
+NetworkManager::ActiveConnection::Ptr NetworkManager::NetworkManagerPrivate::primaryConnection()
+{
+    return findRegisteredActiveConnection(iface.primaryConnection().path());
+}
+
+NetworkManager::ActiveConnection::Ptr NetworkManager::NetworkManagerPrivate::activatingConnection()
+{
+    return findRegisteredActiveConnection(iface.activatingConnection().path());
+}
+
 void NetworkManager::NetworkManagerPrivate::onDeviceAdded(const QDBusObjectPath &objpath)
 {
     nmDebug();
@@ -523,6 +556,14 @@ void NetworkManager::NetworkManagerPrivate::onDeviceRemoved(const QDBusObjectPat
     emit deviceRemoved(objpath.path());
 }
 
+void NetworkManager::NetworkManagerPrivate::connectivityChanged(uint connectivity)
+{
+    if (m_connectivity != connectivity) {
+        m_connectivity = connectivity;
+        emit Notifier::connectivityChanged(convertConnectivity(m_connectivity));
+    }
+}
+
 void NetworkManager::NetworkManagerPrivate::stateChanged(uint state)
 {
     if (nmState != state) {
@@ -595,6 +636,12 @@ void NetworkManager::NetworkManagerPrivate::propertiesChanged(const QVariantMap
             parseVersion(m_version);
         } else if (property == QLatin1String("State")) {
             stateChanged(it->toUInt());
+        } else if (property == QLatin1String("Connectivity")) {
+            connectivityChanged(it->toUInt());
+        } else if (property == QLatin1String("PrimaryConnection")) {
+            emit primaryConnectionChanged(it->value<QDBusObjectPath>().path());
+        } else if (property == QLatin1String("ActivatingConnection")) {
+            emit activatingConnectionChanged(it->value<QDBusObjectPath>().path());
         } else {
             qWarning() << Q_FUNC_INFO << "Unhandled property" << property;
         }
@@ -602,6 +649,29 @@ void NetworkManager::NetworkManagerPrivate::propertiesChanged(const QVariantMap
     }
 }
 
+NetworkManager::Connectivity NetworkManager::NetworkManagerPrivate::convertConnectivity(uint connectivity)
+{
+    NetworkManager::Connectivity convertedConnectivity = NetworkManager::UnknownConnectivity;
+    switch (connectivity) {
+        case NM_CONNECTIVITY_UNKNOWN:
+            convertedConnectivity = NetworkManager::UnknownConnectivity;
+            break;
+        case NM_CONNECTIVITY_NONE:
+            convertedConnectivity = NetworkManager::NoConnectivity;
+            break;
+        case NM_CONNECTIVITY_PORTAL:
+            convertedConnectivity = NetworkManager::Portal;
+            break;
+        case NM_CONNECTIVITY_LIMITED:
+            convertedConnectivity = NetworkManager::Limited;
+            break;
+        case NM_CONNECTIVITY_FULL:
+            convertedConnectivity = NetworkManager::Full;
+            break;
+    }
+    return convertedConnectivity;
+}
+
 NetworkManager::Status NetworkManager::NetworkManagerPrivate::convertNMState(uint state)
 {
     NetworkManager::Status status = NetworkManager::Unknown;
@@ -844,6 +914,26 @@ NetworkManager::Device::Types NetworkManager::supportedInterfaceTypes()
            );
 }
 
+NetworkManager::Connectivity NetworkManager::connectivity()
+{
+    return globalNetworkManager->connectivity();
+}
+
+QDBusPendingReply<uint> NetworkManager::checkConnectivity()
+{
+    return globalNetworkManager->checkConnectivity();
+}
+
+NetworkManager::ActiveConnection::Ptr NetworkManager::primaryConnection()
+{
+    return globalNetworkManager->primaryConnection();
+}
+
+NetworkManager::ActiveConnection::Ptr NetworkManager::activatingConnection()
+{
+    return globalNetworkManager->activatingConnection();
+}
+
 NetworkManager::Notifier *NetworkManager::notifier()
 {
     return globalNetworkManager;
