@@ -18,8 +18,8 @@
     License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#ifndef NETWORKMANAGERQT_SETTINGS_TEMPLATE_P_H
-#define NETWORKMANAGERQT_SETTINGS_TEMPLATE_P_H
+#ifndef NETWORKMANAGERQT_TEMPLATE_SETTING_P_H
+#define NETWORKMANAGERQT_TEMPLATE_SETTING_P_H
 
 #include <QtCore/QString>
 
@@ -37,4 +37,4 @@ public:
 }
 }
 
-#endif // NETWORKMANAGERQT_SETTINGS_TEMPLATE_P_H
+#endif // NETWORKMANAGERQT_TEMPLATE_SETTING_P_H
